@@ -3,12 +3,12 @@ package Net::LDAP::Server::Test;
 use warnings;
 use strict;
 use Carp;
-use IO::Select;
 use IO::Socket;
+use IO::Select;
 use Data::Dump ();
 use Net::LDAP::SID;
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 =head1 NAME
 
@@ -612,7 +612,7 @@ Only one user-level method is implemented: new().
                         =~ s/-1234$/-$gid/;
 
                     my $user_sid = Net::LDAP::SID->new($user_sid_str);
-                    $entry->add( 'objectSID'         => $user_sid->as_binary );
+                    $entry->add( 'objectSID' => $user_sid->as_binary );
                     $entry->add( 'distinguishedName' => $key );
 
                 }
@@ -861,7 +861,7 @@ listing on I<port> and handling requests using Net::LDAP::Server.
 
 I<port> defaults to 10636.
 
-I<port> may be an IO::Socket::INET object listening to a local port.
+I<port> may be an IO::Socket object listening to a local port.
 
 I<key_value_args> may be:
 
@@ -895,6 +895,16 @@ blessed reference to the PID of the forked server.
 
 my %PORTS;    # inside-out tracking of port-per-server
 
+# this snippet matches what Net::LDAP does:
+# check for IPv6 support: prefer IO::Socket::IP 0.20+ over IO::Socket::INET6
+use constant CAN_IPV6 => do {
+    local $SIG{__DIE__};
+
+    eval { require IO::Socket::INET6; }
+        ? 'IO::Socket::INET6'
+        : '';
+};
+
 sub new {
     my $class = shift;
     my $port  = shift || 10636;
@@ -920,12 +930,13 @@ sub new {
             if $ENV{LDAP_DEBUG};
 
         # the child (server)
-        my $sock = ref $port ? $port : IO::Socket::INET->new(
+        my $class = _io_socket_class();
+        my $sock = ref $port ? $port : $class->new(
             Listen    => 5,
             Proto     => 'tcp',
             Reuse     => 1,
             LocalPort => $port
-        ) or die "Unable to listen on port $port: $!";
+        ) or die "Unable to listen on port $port: $! [$@]";
 
         # tickle the pipe to show we've opened ok
         syswrite $w_fh, "Ready\n";
@@ -1032,22 +1043,27 @@ sub stop {
 
 =head2 port_is_open
 
-Returns IO::Socket::INET->new for the current server port.
+Returns an IO::Socket (or subclass) for the current server port.
 If the port is already in use, this is a false value.
 
 =cut
 
 sub port_is_open {
     my $self = shift;
-    my $port = $PORTS{"$self"};
-    return IO::Socket::INET->new(
-        PeerAddr => '127.0.0.1',
+    my $port = shift || $PORTS{"$self"};
+
+    return _io_socket_class()->new(
+        PeerAddr => 'localhost',
         PeerPort => $port,
         Proto    => 'tcp',
         Type     => SOCK_STREAM,
     );
 }
 
+sub _io_socket_class {
+    return CAN_IPV6 ? CAN_IPV6 : 'IO::Socket::INET';
+}
+
 =head1 AUTHOR
 
 Peter Karman, C<< <karman at cpan.org> >>
